@@ -1,14 +1,22 @@
-#' Specify the response and explanatory variables
+#' Specify response and explanatory variables
 #'
-#' `specify()` also converts character variables chosen to be `factor`s.
+#' @description
+#' \Sexpr[results=rd, stage=render]{lifecycle::badge("maturing")}
+#'  
+#' `specify()` is used to specify which columns in the supplied data frame are
+#' the relevant response (and, if applicable, explanatory) variables. Note that 
+#' character variables are converted to `factor`s.
+#' 
+#' Learn more in `vignette("infer")`.
 #'
 #' @param x A data frame that can be coerced into a [tibble][tibble::tibble].
 #' @param formula A formula with the response variable on the left and the
-#'   explanatory on the right.
+#'   explanatory on the right. Alternatively, a `response` and `explanatory`
+#'   argument can be supplied.
 #' @param response The variable name in `x` that will serve as the response.
-#'   This is alternative to using the `formula` argument.
+#'   This is an alternative to using the `formula` argument.
 #' @param explanatory The variable name in `x` that will serve as the
-#'   explanatory variable.
+#'   explanatory variable. This is an alternative to using the formula argument.
 #' @param success The level of `response` that will be considered a success, as
 #'   a string. Needed for inference on one proportion, a difference in
 #'   proportions, and corresponding z stats.
@@ -17,13 +25,20 @@
 #'   variable data.
 #'
 #' @examples
-#' # Permutation test similar to ANOVA
-#' mtcars %>%
-#'   dplyr::mutate(cyl = factor(cyl)) %>%
-#'   specify(mpg ~ cyl) %>%
-#'   hypothesize(null = "independence") %>%
-#'   generate(reps = 100, type = "permute") %>%
-#'   calculate(stat = "F")
+#' # specifying for a point estimate on one variable
+#' gss %>%
+#'    specify(response = age)
+#' 
+#' # specify a relationship between variables as a formula...
+#' gss %>%
+#'   specify(age ~ partyid)
+#'   
+#' # ...or with named arguments!
+#' gss %>%
+#'   specify(response = age, explanatory = partyid)
+#'
+#' # More in-depth explanation of how to use the infer package
+#' vignette("infer")
 #'
 #' @importFrom rlang f_lhs
 #' @importFrom rlang f_rhs
@@ -126,19 +141,19 @@ parse_variables <- function(x, formula, response = NULL,
   }
   if (methods::hasArg(formula)) {
     tryCatch(
-      formula_arg_is_formula <- rlang::is_formula(formula), 
+      rlang::is_formula(formula), 
       error = function(e) {
         stop_glue("The argument you passed in for the formula does not exist.
                   * Were you trying to pass in an unquoted column name?
                   * Did you forget to name one or more arguments?")
       }
-        )
-    if (!formula_arg_is_formula) {
+    )
+    if (!rlang::is_formula(formula)) {
       stop_glue("The first unnamed argument must be a formula.
                 * You passed in '{get_type(formula)}'.
                 * Did you forget to name one or more arguments?")
     }
-    }
+  }
   
   attr(x, "response")    <- get_expr(response)
   attr(x, "explanatory") <- get_expr(explanatory)
@@ -148,35 +163,53 @@ parse_variables <- function(x, formula, response = NULL,
     attr(x, "explanatory") <- f_rhs(formula)
   }
   
-  if (is_nuat(x, "response")) {
+  # Check response and explanatory variables to be appropriate for later use
+  if (!has_response(x)) {
     stop_glue("Supply not `NULL` response variable.")
   }
-  
-  if (!(as.character(attr(x, "response")) %in% names(x))) {
-    stop_glue(
-      'The response variable `{attr(x, "response")}` cannot be found in this ',
-      'dataframe.'
-    )
-  }
+  check_var_correct(x, "response")
+  check_var_correct(x, "explanatory")
   
   # If there's an explanatory var
-  if (has_explanatory(x)) {
-    if (!as.character(attr(x, "explanatory")) %in% names(x)) {
+  check_vars_different(x)
+  
+  x
+}
+
+check_var_correct <- function(x, var_name) {
+  var <- attr(x, var_name)
+  
+  # Variable (if present) should be a symbolic column name
+  if (!is.null(var)) {
+    if (!rlang::is_symbolic(var)) {
       stop_glue(
-        'The explanatory variable `{attr(x, "explanatory")}` cannot be found ',
-        'in this dataframe.'
+        "The {var_name} should be a bare variable name (not a string in ",
+        "quotation marks)."
       )
     }
-    if (
-      identical(
-        as.character(attr(x, "response")), as.character(attr(x, "explanatory"))
+    
+    if (!(as.character(var) %in% names(x))) {
+      stop_glue(
+        'The {var_name} variable `{var}` cannot be found in this dataframe.'
       )
-    ) {
+    }
+  }
+  
+  TRUE
+}
+
+check_vars_different <- function(x) {
+  if (has_response(x) && has_explanatory(x)) {
+    res_var <- as.character(attr(x, "response"))
+    exp_var <- as.character(attr(x, "explanatory"))
+    
+    if (identical(res_var, exp_var)) {
       stop_glue(
         "The response and explanatory variables must be different from one ",
         "another."
       )
     }
   }
-  return(x)
+  
+  TRUE
 }
